---
title: Remote Desktop Access
keywords: NX, nomachine, remote desktop access, login node, login001, login002, merlin7-nx-01, merlin7-nx-02, merlin7-nx, rem-acc, VPN, browser access
last_updated: 07 August 2024
sidebar: merlin7_sidebar
permalink: /merlin7/nomachine.html
---

Users can log in to Merlin through a Linux Remote Desktop Session. NoMachine is a desktop virtualization tool similar to VNC, Remote Desktop, etc. It uses the NX protocol to enable a graphical login to remote servers.

## New Feature: Browser-Based Access

We have now enabled browser-based access to Merlin7. This allows users to connect to the NoMachine service directly through a web browser, removing the need to install a client application. This is accessible via the following URL:

- **Browser Endpoint**: [https://merlin7-nx.psi.ch:4443](https://merlin7-nx.psi.ch:4443)

### How to Connect via Browser

1. Open your web browser and navigate to [https://merlin7-nx.psi.ch:4443](https://merlin7-nx.psi.ch:4443).
2. Enter your credentials when prompted. **Do not add `PSICH\`** as a prefix for the username.
3. Follow the on-screen instructions to launch a new session or reconnect to an existing one.

## Installation

For traditional access, NoMachine is available for PSI Windows computers in the Software Kiosk under the name **NX Client**. Please use the latest version (at least 8.1.3). For macOS and Linux, the NoMachine client can be downloaded from [https://www.nomachine.com/](https://www.nomachine.com/).

## Accessing Merlin7 NoMachine from PSI

The Merlin7 NoMachine service is hosted on the following machine:

- **`merlin7-nx.psi.ch`**

This is the **front-end** (hence, *the door*) to the NoMachine **back-end nodes**, which contain the NoMachine desktop service. The **back-end nodes** are the following:

- `login001.merlin7.psi.ch`
- `login002.merlin7.psi.ch`

Any access to the login node desktops must be done through **`merlin7-nx.psi.ch`**.

The **front-end** service running on **`merlin7-nx.psi.ch`** will load-balance the sessions and log in to any available nodes in the **back-end**.

**Only one session per back-end** is possible.

Below are all the steps necessary for configuring access to the NoMachine service running on a login node.

### Creating a Merlin7 NoMachine Connection

#### Adding a New Connection to the Front-End

Click the **Add** button to create a new connection to the **`merlin7-nx.psi.ch` front-end**, and fill up the following fields:

- **Name**: Specify a custom name for the connection. Examples: `merlin7-nx`, `merlin7-nx.psi.ch`, `Merlin Desktop`
- **Host**: Specify the hostname of the **front-end** service: **`merlin7-nx.psi.ch`**
- **Protocol**: Specify the protocol that will be used for the connection. *Recommended* protocol: **`NX`**
- **Port**: Specify the listening port of the **front-end**. It must be **`4000`** for the **`NX`** protocol.

![Create New NoMachine Connection]({{ "/images/NoMachine/screen_nx_connect.png" }})

#### Configuring NoMachine Authentication Method

Depending on the client version, it may ask for different authentication options. If required, choose your authentication method and **Continue** (**Password** or *Kerberos* are recommended).

You will be requested for the credentials (username/password). **Do not add `PSICH\`** as a prefix for the username.

### Opening NoMachine Desktop Sessions

By default, when connecting to the **`merlin7-nx.psi.ch` front-end**, a new session automatically opens if none exists.

If there are existing sessions, users can reconnect to an existing one instead of opening a new desktop session by clicking the appropriate icon (see image below).

![Open an existing Session]({{ "/images/NoMachine/screen_nx_existingsession.png" }})

Users can also create a second desktop session by selecting the **`New Desktop`** button (*red* rectangle in the image below). This will create a second session on the second login node as long as it is up and running.

![Open a New Desktop]({{ "/images/NoMachine/screen_nx_newsession.png" }})

### NoMachine LightDM Session Example

An example of the NoMachine session, which is based on [LightDM](https://github.com/canonical/lightdm) X Windows:

![NoMachine Session: LightDM Desktop]({{ "/images/NoMachine/screen_nx11.png" }})

## Accessing Merlin7 NoMachine from Outside PSI

### No Direct Access Without VPN

During the pre-production phase, direct access to the NoMachine service from outside the organization is not supported. To access the service, you must first connect to PSI's VPN. The external **rem-acc.psi.ch** service does not yet allow direct access to the new cluster without a VPN connection.

### VPN Access

Remote access is possible through VPN; however, you **must not use 'rem-acc.psi.ch'**, and you have to connect directly to the Merlin7 NoMachine **`merlin7-nx.psi.ch` front-end** as if you were inside PSI. For VPN access, you should request it from the IT department by opening a PSI Service Now ticket: [VPN Access (PSI employees)](https://psi.service-now.com/psisp?id=psi_new_sc_cat_item&sys_id=beccc01b6f44a200d02a82eeae3ee440).

## Advanced Display Settings

**NoMachine Display Settings** can be accessed and changed when creating a new session or by clicking the top right corner of a running session.

### Prevent Rescaling

These settings prevent "blurriness" at the cost of some performance! (You might want to choose depending on performance)

- Display > Resize remote display (forces 1:1 pixel sizes)
- Display > Change settings > Quality: Choose Medium-Best Quality
- Display > Change settings > Modify advanced settings
  - Check: Disable network-adaptive display quality (turns off lossy compression)
  - Check: Disable client-side image post-processing
